@@ -10,12 +10,16 @@
 # sys.setrecursionlimit(n)
 
 from pnap_rancher_solution_api.model.cluster import Cluster
+from pnap_rancher_solution_api.model.cluster_configuration import ClusterConfiguration
+from pnap_rancher_solution_api.model.cluster_workload_configuration import ClusterWorkloadConfiguration
 from pnap_rancher_solution_api.model.delete_result import DeleteResult
 from pnap_rancher_solution_api.model.error import Error
 from pnap_rancher_solution_api.model.node import Node
 from pnap_rancher_solution_api.model.node_pool import NodePool
+from pnap_rancher_solution_api.model.node_pool_ssh_config import NodePoolSshConfig
 from pnap_rancher_solution_api.model.rancher_cluster_certificates import RancherClusterCertificates
 from pnap_rancher_solution_api.model.rancher_cluster_config import RancherClusterConfig
+from pnap_rancher_solution_api.model.rancher_cluster_config_certificates import RancherClusterConfigCertificates
 from pnap_rancher_solution_api.model.rancher_server_metadata import RancherServerMetadata
 from pnap_rancher_solution_api.model.ssh_config import SshConfig
 from pnap_rancher_solution_api.model.workload_cluster_config import WorkloadClusterConfig
